@@ -3,8 +3,16 @@ from tw.api import Widget
 from tw.forms import HiddenField
 from configbase import ConfigBase, ConfigBaseError
 from sqlalchemy.orm import PropertyLoader
+from sqlalchemy.schema import Column
 from widgetselector import WidgetSelector
 
+#sa 0.5 support
+try:  #pragma:no cover
+    from sqlalchemy.types import Enum
+except:  #pragma:no cover
+    class Enum:
+        pass
+
 class ClassViewer(object):
     """class wrapper to expose items of a class.  Needed to pass classes to TW as params"""
     def __init__(self, klass):
@@ -133,6 +141,16 @@ class ViewBase(ConfigBase):
             entity = ClassViewer(field)
 
         args = {'id':field_name, 'identity':self.__entity__.__name__+'_'+field_name, 'entity':entity}
+        if isinstance(entity, Column) and entity.default:
+            if isinstance(entity.default.arg, str) or \
+               isinstance(entity.default.arg, unicode) or \
+               isinstance(entity.default.arg, int) or \
+               isinstance(entity.default.arg, float):
+                    args['default'] = entity.default.arg
+
+        #enum support works completely differently.
+        #if isinstance(entity, Column) and isinstance(entity.type, Enum):
+        #    args['options'] = entity.type.enums
 
         if field_name in self.__field_attrs__:
             args['attrs'] = self.__field_attrs__[field_name]
